Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2277)

Unified Diff: editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java

Issue 15853005: Change the cmd-line output for warnings from foo.dart:line:col to foo.dart, line x, col y. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java
===================================================================
--- editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java (revision 23419)
+++ editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java (working copy)
@@ -104,8 +104,8 @@
length,
escapePipe(error.getMessage())));
} else {
- // [warning] 'foo' is not a method or function (/Users/devoncarew/temp/foo.dart:-1:-1)
- out.println(String.format("[%s] %s (%s:%d:%d)", //
+ // [warning] 'foo' is not a method or function (/Users/devoncarew/tmp/foo.dart, line 1, col 2)
+ out.println(String.format("[%s] %s (%s, line %d, col %d)", //
error.getErrorCode().getErrorSeverity().getDisplayName(),
error.getMessage(),
source.getFullName(),

Powered by Google App Engine
This is Rietveld 408576698